Method: Shippinglogic::FedEx::Proxy#method_missing

Defined in:
lib/shippinglogic/fedex/proxy.rb

#method_missing(name, *args, &block) ⇒ Object (protected)

We undefined a lot of methods at the beginning of this class. The only methods present in this class are ones that we need, everything else is delegated to our target object.



16
17
18
# File 'lib/shippinglogic/fedex/proxy.rb', line 16

def method_missing(name, *args, &block)
  target.send(name, *args, &block)
end